//-----------------------------------------------------------------------------
//Test_Ufw_Tin_Msl.java
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
//Package Definition
//-----------------------------------------------------------------------------
package uicc.usim.test.usatframework.ufw_tin_msl;

import org._3gpp.ct.wg6.usim.jcapi.userclass.*;
import org.etsi.scp.wg3.uicc.jcapi.userclass.*;
import org.etsi.scp.wg3.uicc.jcapi.userinterface.*;

//-----------------------------------------------------------------------------
//Imports
//-----------------------------------------------------------------------------

/**
 * Test Area : uicc.usim.test.ufwk.ufw_tin_msl
 *
 * @version 0.0.1 - 12 sept. 2005
 * @author 3GPP T3 SWG API
 */
public class Test_Ufw_Tin_Msl extends UiccTestModel {


    static final String             CAP_FILE_PATH   = "uicc/usim/test/usatframework/ufw_tin_msl";

    private final String            CLASS_AID_1     = "A0000000 871005FF FFFFFF89 50010001";
    private final String            APPLET_AID_1    = "A0000000 871005FF FFFFFF89 50010102";
    
    /** */
    private USimAPITestCardService test;
    /** contains the response of the processed apdu*/
    private APDUResponse response;

    private static String           ADF_1_AID           = "A0000000090005FFFFFFFF89E0000002";;
    /** */
    public Test_Ufw_Tin_Msl() {
        test = USimAPITestCardService.getTheUSimTestCardService();
    }
    /**
     * @todo terminal profile
     */
    public boolean run() {
            
            initialiseResults();
         
            // test script
            test.reset();
            test.terminalProfile("0301");
            // Install package
            test.loadPackage(CAP_FILE_PATH);
            
            // Test case 1 : Installation with MSL length set to 0
            
            // 1.1 Install Applet1
            test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1, 
                                "8008" + // TLV UICC Toolkit application specific parameters
                                "01" +   // V Priority Level
                                "00" +   // V Max. number of timers
                                "00" +   // V Maximum text length for a menu entry
                                "00" +   // V Maximum number of menu entries                              
                                "00" +   // V Maximum number of channels 
                                "00" +   // LV Minimum Security Level field
                                "00" +   // LV TAR Value(s) 
                                "00" );  // V Maximum number of services
            
          
            // terminal profile
            test.terminalProfileSession("03010000 0102");
            
            // 1.2 Single SMSPP is sent to applet1 without any security
            response = test.envelopeSmsPp("8B254008 81556677 887FF600 11291200"
                                        + "00041402 7000000F 0D080010 10500101"
                                        + "00000000 010005");
            addResult(response.checkSw("9000"));

            // 1.3 : Single authenticated and ciphered Envelope(SMS_PP).
            response = test.envelopeSmsPp("8B364008 81556677 887FF600 11291200"
                                        + "00042502 70000020 150E0111 11500101"
                                        + "39750E40 FB451508 CDFD528A 873B8547"
                                        + "30C884F6 B4D8A69A");
            addResult(response.checkSw("9000"));
            
            //get test result
            response = test.selectApplication(APPLET_AID_1);
            addResult(response.checkData("10"+APPLET_AID_1+
                                         "02CCCC"));

            // 1.4 Delete the applet instance
            test.reset();
            
            // terminal profile
            test.terminalProfileSession("03010000 0102");
            
            test.deleteApplet(APPLET_AID_1);
            
            // Test case 2 Installation with correct MSL value

            // 2.1 Install applet1 with MSL set to 02 (CC required)
            test.installApplet(CAP_FILE_PATH, CLASS_AID_1, APPLET_AID_1, 
                               "800A" + // TLV UICC Toolkit application specific parameters
                               "01" +   // V Priority Level
                               "00" +   // V Max. number of timers
                               "00" +   // V Maximum text length for a menu entry
                               "00" +   // V Maximum number of menu entries                              
                               "00" +   // V Maximum number of channels 
                               "020102" + // LV Minimum Security Level field
                               "00" +   // LV TAR Value(s) 
                               "00" );  // V Maximum number of services

            

            // 2.2 Single SMSPP is sent to applet1 without any security
            response = test.envelopeSmsPp("8B254008 81556677 887FF600 11291200"
                                        + "00041402 7000000F 0D080010 10500101"
                                        + "00000000 010005");
            addResult(response.checkSw("9000"));

            // 2.3 Single SMSPP is sent to applet1 with CC, no ciphering and counter mode 1
            response = test.envelopeSmsPp("8B2D4008 81556677 887FF600 11291200"
                                        + "00041C02 70000017 150A0011 11500101"
                                        + "00000000 01007555 32F9DFED 25D600");
            addResult(response.checkSw("9000"));

            // 2.4 Single SMSPP is sent to applet 1 with no CC, ciphered and counter mode 0
            response = test.envelopeSmsPp("8B264008 81556677 887FF600 11291200"
                                        + "00041502 70000010 0D040111 11500101"
                                        + "94635689 B35BA8C6");
            // Check the SW and the response status code
            addResult(response.checkSw("6200"));
            addResult(response.getData().substring(0x1E).equalsIgnoreCase("0A"));
            
            //get test result
            response = test.selectApplication(APPLET_AID_1);
            addResult(response.checkData("10"+APPLET_AID_1+
                                         "01CC"));
            
            // delete applet and package
            test.reset();
            test.terminalProfile("0301");
            test.deleteApplet(APPLET_AID_1);
            test.deletePackage(CAP_FILE_PATH);

            return getOverallResult();
    }
}
